@@ -4,7 +4,6 @@ import unittest
 import tempfile
 import shutil
 import os
-import sys
 from unittest import mock
 
 from click.testing import CliRunner
@@ -105,7 +104,7 @@ class TestInstall(unittest.TestCase):
             mock_subprocess.call_count == 2
             mock_subprocess.assert_any_call(
                 [
-                    sys.executable,
+                    f"{os.environ['HOME']}/.pyenv/shims/python",
                     "-m",
                     "pip",
                     "install",
@@ -127,7 +126,7 @@ class TestInstall(unittest.TestCase):
             mock_subprocess.call_count == 2
             mock_subprocess.assert_any_call(
                 [
-                    sys.executable,
+                    f"{os.environ['HOME']}/.pyenv/shims/python",
                     "-m",
                     "pip",
                     "install",
@@ -147,11 +146,11 @@ class TestInstall(unittest.TestCase):
         mock_list_dir.return_value = ['some_package.tar.gz']
         gs_pip_install.install_packages(
             packages_download_dir='some_download_dest',
-            extras={'some_package': 'extra_a, extra_b'},
+            extras={'some_package': '[extra_a, extra_b]'},
         )
         mock_subprocess.assert_called_once_with(
             [
-                sys.executable,
+                f"{os.environ['HOME']}/.pyenv/shims/python",
                 "-m",
                 "pip",
                 "install",
@@ -160,3 +159,13 @@ class TestInstall(unittest.TestCase):
                 "some_download_dest/some_package.tar.gz[extra_a, extra_b]",
             ]
         )
+
+    def test_strip_extras(self):
+
+        # fmt: off
+        assert gs_pip_install._strip_extras(
+            'some_package.tar.gz[extra_a, extra_b]'
+        ) == (
+            'some_package.tar.gz', '[extra_a, extra_b]'
+        )
+        # fmt: on
